"""
// (c) University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road,
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Nikolay Stanchev
//      Created Date :          15-05-2018
//      Created for Project :   FLAME
"""


import os
import os.path
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


def get_version(fname):
    if os.path.isfile(fname):
      git_revision = read(fname)
    else:
      git_revision = "SNAPSHOT"

    return git_revision


requires = [
    'plaster_pastedeploy',
    'pyramid',
    'pyramid_debugtoolbar',
    'pyramid_exclog',
    'waitress',
    'sqlalchemy',
    'zope.sqlalchemy',
    'psycopg2',
    'influxdb',
    'neo4j-driver',
    'py2neo'
]

tests_require = [
    'pytest',
    'pytest-cov'
]

setup(
    name="clmcservice",
    version=get_version("_version.py"),
    author="Michael Boniface",
    author_email="mjb@it-innovation.soton.ac.uk",
    description="FLAME CLMC Service Module",
    long_description="FLAME CLMC Service",
    license="https://gitlab.it-innovation.soton.ac.uk/FLAME/flame-clmc/blob/integration/LICENSE",
    keywords="FLAME CLMC service",
    url='https://gitlab.it-innovation.soton.ac.uk/FLAME/flame-clmc',
    packages=find_packages(),
    include_package_data=True,
    install_requires=requires,
    extras_require={
        'testing': tests_require,
    },
    package_data={'': ['_version.py']},
    classifiers=[
        "Development Status :: Alpha",
        "Topic :: FLAME CLMC Service",
        "License :: ",
    ],
    entry_points={
        'paste.app_factory': [
            'main = clmcservice:main',
        ],
        'console_scripts': [
            'initialize_clmcservice_db = clmcservice.initialize_db:main',
        ]
    },
)
